import { NgStyle } from '@angular/common';
import * as i0 from '@angular/core';
import { signal, inject, input, output, viewChild, effect, untracked, ChangeDetectionStrategy, Component } from '@angular/core';
import { LibsUiComponentsPopoverComponent } from '@libs-ui/components-popover';
import { LibsUiComponentsSpinnerComponent } from '@libs-ui/components-spinner';
import { LibsUiConfigProjectService } from '@libs-ui/services-config-project';
import { UtilsKeyCodeConstant, get, colorContrastFromOrigin } from '@libs-ui/utils';
import * as i1 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';
import { Subject, fromEvent, timer } from 'rxjs';
import { takeUntil } from 'rxjs/operators';

/* eslint-disable @typescript-eslint/no-explicit-any */
class LibsUiComponentsButtonsButtonComponent {
    // #region PROPERTY
    onDestroy = new Subject();
    classBinding = signal('');
    isClick = signal(false);
    typeIconLoading = signal('spin-blue');
    typeButton = signal(false);
    configProjectService = inject(LibsUiConfigProjectService);
    // #region INPUT
    flagMouse = input({ isMouseEnter: false, isMouseEnterContent: false, isContainerHasScroll: false });
    type = input('button-primary');
    buttonCustom = input(); // bắt buộc khi type là button-custom hoặc button-link-custom
    sizeButton = input('medium', { transform: value => value ?? 'medium' });
    label = input(' ');
    disable = input(false);
    isPending = input();
    imageLeft = input();
    classInclude = input('');
    classIconLeft = input('');
    classIconRight = input('');
    classLabel = input('');
    iconOnlyType = input(false);
    popover = input({});
    ignoreStopPropagationEvent = input(true, { transform: val => val ?? true });
    zIndex = input(10);
    widthLabelPopover = input();
    styleIconLeft = input();
    styleButton = input();
    ignoreFocusWhenInputTab = input(); // dùng để bỏ qua focus khi bấm nút TAB từ bán phím
    ignoreSetClickWhenShowPopover = input();
    ignorePointerEvent = input();
    isActive = input();
    isHandlerEnterDocumentClickButton = input();
    // #region OUTPUT
    outClick = output();
    outPopoverEvent = output();
    outFunctionsControl = output();
    /* VIEW CHILD */
    buttonEl = viewChild.required('buttonEl');
    constructor() {
        effect(() => {
            this.type();
            this.buttonCustom();
            untracked(() => this.setClassByType());
        });
    }
    ngAfterViewInit() {
        if (!this.isHandlerEnterDocumentClickButton()) {
            return;
        }
        fromEvent(document, 'keyup').pipe(takeUntil(this.onDestroy)).subscribe((e) => {
            if (e.keyCode !== UtilsKeyCodeConstant.ENTER) {
                return;
            }
            this.handlerClick(e);
        });
    }
    /* FUNCTIONS */
    handlerClick(e) {
        if (!this.ignoreStopPropagationEvent()) {
            e.stopPropagation();
        }
        this.buttonEl()?.nativeElement.blur();
        if (this.disable() || this.isPending()) {
            return;
        }
        this.outClick.emit(e);
        this.isClick.set(true);
        timer(100).pipe(takeUntil(this.onDestroy)).subscribe(() => {
            this.isClick.set(false);
        });
    }
    async handlerPopoverControlEvent(control) {
        this.outFunctionsControl.emit(control);
    }
    async setClassByType() {
        if (this.type().search('button') === 0) {
            this.typeButton.set(true);
        }
        this.setClassAndIconLoadingByType();
        const config = this.type().includes('custom') ? this.buttonCustom() : get(this.configProjectService.ConfigButton(), this.type());
        this.setVariableStyles(config.rootColor, config.configStepColor);
        if (!this.sizeButton || !this.typeButton()) {
            return this.classBinding.update(value => `${value} ${this.classInclude()}`);
        }
        switch (this.sizeButton()) {
            case 'large':
                return this.classBinding.update(value => `${value} ${this.classInclude()} libs-ui-button-large`);
            case 'medium':
                return this.classBinding.update(value => `${value} ${this.classInclude()} libs-ui-button-medium`);
            case 'small':
                return this.classBinding.update(value => `${value} ${this.classInclude()} libs-ui-button-small`);
            case 'smaller':
                return this.classBinding.update(value => `${value} ${this.classInclude()} libs-ui-button-smaller`);
        }
    }
    async setClassAndIconLoadingByType() {
        if (!this.type) {
            return;
        }
        if (this.type().includes('link')) {
            this.classBinding.set('libs-ui-button libs-ui-button-theme libs-ui-button-link libs-ui-button-link-other-color');
            return this.typeIconLoading.set('spin-blue');
        }
        this.classBinding.set('libs-ui-button libs-ui-button-theme libs-ui-button-other-color');
        if (['button-secondary', 'button-third', 'button-outline', 'button-outline-green'].includes(this.type())) {
            return this.typeIconLoading.set('spin-blue');
        }
        return this.typeIconLoading.set('spin-white');
    }
    async setVariableStyles(color, configStep) {
        if (!color) {
            return;
        }
        const colors = colorContrastFromOrigin(color);
        Object.keys(configStep).forEach(key => {
            const valueStep = get(configStep, key);
            const typeLink = this.type().includes('link');
            if (typeof valueStep === 'string') {
                this.buttonEl()?.nativeElement.style.setProperty(`--libs-ui-button${typeLink ? '-link' : ''}-other-color-${key.replace('_', '-')}`, valueStep);
                return;
            }
            const color = colors.find(item => item.step === Math.abs(valueStep));
            this.buttonEl()?.nativeElement.style.setProperty(`--libs-ui-button${typeLink ? '-link' : ''}-other-color-${key.replace('_', '-')}`, get(color || {}, valueStep < 0 ? 'dark' : 'light'));
        });
    }
    async handlerPopoverEvent(event) {
        this.outPopoverEvent.emit(event);
        if (event === 'click') {
            return;
        }
        if (event === 'remove') {
            this.isClick.set(false);
            return;
        }
        if (!this.ignoreSetClickWhenShowPopover()) {
            this.isClick.set(true);
        }
    }
    ngOnDestroy() {
        this.onDestroy.next();
        this.onDestroy.complete();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LibsUiComponentsButtonsButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: LibsUiComponentsButtonsButtonComponent, isStandalone: true, selector: "libs_ui-components-buttons-button", inputs: { flagMouse: { classPropertyName: "flagMouse", publicName: "flagMouse", isSignal: true, isRequired: false, transformFunction: null }, type: { classPropertyName: "type", publicName: "type", isSignal: true, isRequired: false, transformFunction: null }, buttonCustom: { classPropertyName: "buttonCustom", publicName: "buttonCustom", isSignal: true, isRequired: false, transformFunction: null }, sizeButton: { classPropertyName: "sizeButton", publicName: "sizeButton", isSignal: true, isRequired: false, transformFunction: null }, label: { classPropertyName: "label", publicName: "label", isSignal: true, isRequired: false, transformFunction: null }, disable: { classPropertyName: "disable", publicName: "disable", isSignal: true, isRequired: false, transformFunction: null }, isPending: { classPropertyName: "isPending", publicName: "isPending", isSignal: true, isRequired: false, transformFunction: null }, imageLeft: { classPropertyName: "imageLeft", publicName: "imageLeft", isSignal: true, isRequired: false, transformFunction: null }, classInclude: { classPropertyName: "classInclude", publicName: "classInclude", isSignal: true, isRequired: false, transformFunction: null }, classIconLeft: { classPropertyName: "classIconLeft", publicName: "classIconLeft", isSignal: true, isRequired: false, transformFunction: null }, classIconRight: { classPropertyName: "classIconRight", publicName: "classIconRight", isSignal: true, isRequired: false, transformFunction: null }, classLabel: { classPropertyName: "classLabel", publicName: "classLabel", isSignal: true, isRequired: false, transformFunction: null }, iconOnlyType: { classPropertyName: "iconOnlyType", publicName: "iconOnlyType", isSignal: true, isRequired: false, transformFunction: null }, popover: { classPropertyName: "popover", publicName: "popover", isSignal: true, isRequired: false, transformFunction: null }, ignoreStopPropagationEvent: { classPropertyName: "ignoreStopPropagationEvent", publicName: "ignoreStopPropagationEvent", isSignal: true, isRequired: false, transformFunction: null }, zIndex: { classPropertyName: "zIndex", publicName: "zIndex", isSignal: true, isRequired: false, transformFunction: null }, widthLabelPopover: { classPropertyName: "widthLabelPopover", publicName: "widthLabelPopover", isSignal: true, isRequired: false, transformFunction: null }, styleIconLeft: { classPropertyName: "styleIconLeft", publicName: "styleIconLeft", isSignal: true, isRequired: false, transformFunction: null }, styleButton: { classPropertyName: "styleButton", publicName: "styleButton", isSignal: true, isRequired: false, transformFunction: null }, ignoreFocusWhenInputTab: { classPropertyName: "ignoreFocusWhenInputTab", publicName: "ignoreFocusWhenInputTab", isSignal: true, isRequired: false, transformFunction: null }, ignoreSetClickWhenShowPopover: { classPropertyName: "ignoreSetClickWhenShowPopover", publicName: "ignoreSetClickWhenShowPopover", isSignal: true, isRequired: false, transformFunction: null }, ignorePointerEvent: { classPropertyName: "ignorePointerEvent", publicName: "ignorePointerEvent", isSignal: true, isRequired: false, transformFunction: null }, isActive: { classPropertyName: "isActive", publicName: "isActive", isSignal: true, isRequired: false, transformFunction: null }, isHandlerEnterDocumentClickButton: { classPropertyName: "isHandlerEnterDocumentClickButton", publicName: "isHandlerEnterDocumentClickButton", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { outClick: "outClick", outPopoverEvent: "outPopoverEvent", outFunctionsControl: "outFunctionsControl" }, viewQueries: [{ propertyName: "buttonEl", first: true, predicate: ["buttonEl"], descendants: true, isSignal: true }], ngImport: i0, template: "<libs_ui-components-popover [type]=\"popover().type || 'other'\"\n  [mode]=\"popover().mode || 'hover'\"\n  [ignoreHiddenPopoverContentWhenMouseLeave]=\"popover().ignoreHiddenPopoverContentWhenMouseLeave || false\"\n  [ignoreShowPopover]=\"popover().config ? !!popover().ignoreShowPopover : true\"\n  [elementRefCustom]=\"popover().elementRefCustom\"\n  [config]=\"popover().config || {}\"\n  [flagMouse]=\"flagMouse()\"\n  [ignoreStopPropagationEvent]=\"ignoreStopPropagationEvent()\"\n  (outFunctionsControl)=\"handlerPopoverControlEvent($event)\"\n  (outEvent)=\"handlerPopoverEvent($event)\">\n  <button #buttonEl\n    [class]=\"classBinding()\"\n    [class.libs-ui-button-disable]=\"disable()\"\n    [class.pointer-events-none]=\"disable() && !ignorePointerEvent()\"\n    [attr.isPending]=\"isPending()\"\n    [attr.isClick]=\"isClick()\"\n    [attr.tabindex]=\"ignoreFocusWhenInputTab()?'-1':'0'\"\n    [attr.hasLabel]=\"((label() || ' ') | translate) !== ' '\"\n    [attr.hasIconLeft]=\"!!classIconLeft()\"\n    [attr.hasIconRight]=\"!!classIconRight()\"\n    [attr.active]=\"!!isActive()\"\n    [ngStyle]=\"styleButton()\"\n    (click)=\"handlerClick($event)\">\n    @if (imageLeft(); as imageConfig) {\n      <img [src]=\"imageConfig.src\"\n        [class]=\"imageConfig.classInclude || 'mr-[8px]'\" />\n    }\n    @if (classIconLeft() && (!iconOnlyType() || (iconOnlyType() && !isPending()))) {\n      <i [attr.iconOnlyType]=\"iconOnlyType()\"\n        [class]=\"classIconLeft() + ' libs-ui-button-icon-left'\"\n        [ngStyle]=\"styleIconLeft()\">\n      </i>\n    }\n    @if (!iconOnlyType()) {\n      <libs_ui-components-popover [type]=\"'text'\"\n        [config]=\"{\n        zIndex: zIndex(),\n        width: widthLabelPopover()\n      }\"\n        [class]=\"(classLabel() || '') + ' libs-ui-button-label'\"\n        [innerHtml]=\"(label() || ' ') | translate\"\n        [ignoreStopPropagationEvent]=\"ignoreStopPropagationEvent()\" />\n    }\n    @if (classIconRight() && (!iconOnlyType() || (iconOnlyType() && !isPending()))) {\n      <i [attr.iconOnlyType]=\"iconOnlyType()\"\n        [class]=\"classIconRight()+' libs-ui-button-icon-right'\"></i>\n    }\n    @if (isPending()) {\n      <div class=\"relative\"\n        [class.w-[16px]]=\"!typeButton() && !iconOnlyType()\"\n        [class.left-[16px]]=\"!typeButton() && !iconOnlyType()\"\n        [class.ml-[8px]]=\"typeButton() && !iconOnlyType()\">\n        <libs_ui-components-spinner [type]=\"typeIconLoading()\"\n          [size]=\"sizeButton() === 'large'?'medium':sizeButton() === 'smaller'?'smaller':'small'\" />\n      </div>\n    }\n  </button>\n</libs_ui-components-popover>\n", styles: [".libs-ui-button{display:flex;align-items:center;text-align:center;color:#fff;cursor:pointer}.libs-ui-button.libs-ui-button-theme{display:flex;align-items:center;font-size:var(--libs-ui-button-size-medium-font-size, 12px);line-height:var(--libs-ui-button-size-medium-line-height, 18px);text-align:center;color:#fff;border:none;border-radius:4px;cursor:pointer}.libs-ui-button.libs-ui-button-theme:focus,.libs-ui-button.libs-ui-button-theme[isClick=true]{outline:none;box-shadow:none}.libs-ui-button.libs-ui-button-theme .libs-ui-button-icon-left[iconOnlyType=false]{margin-right:8px}.libs-ui-button.libs-ui-button-theme .libs-ui-button-icon-right[iconOnlyType=false]{margin-left:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large{border-radius:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large[hasLabel=true]{padding:9px 16px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large>[class*=libs-ui-button-icon]{font-size:var(--libs-ui-button-size-icon-large, 20px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large[hasIconLeft=true]{padding-left:12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large[hasIconRight=true]{padding-right:12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large[hasLabel=false]{padding:11px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large span,.libs-ui-button.libs-ui-button-theme.libs-ui-button-large .libs-ui-button-label{font-size:var(--libs-ui-button-size-large-font-size, 16px);font-family:var(--libs-ui-font-family-name, \"Arial\");font-weight:500;line-height:var(--libs-ui-button-size-large-line-height, 24px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium[hasLabel=true]{padding:6px 16px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium[hasIconLeft=true]{padding-left:12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium[hasIconRight=true]{padding-right:12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium[hasLabel=false]{padding:7px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium>[class*=libs-ui-button-icon]{font-size:var(--libs-ui-button-size-icon-medium, 16px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium span,.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium .libs-ui-button-label{font-size:var(--libs-ui-button-size-medium-font-size, 12px);line-height:var(--libs-ui-button-size-medium-line-height, 18px);font-family:var(--libs-ui-font-family-name, \"Arial\");font-weight:500}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small[hasLabel=true]{padding:4px 12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small[hasIconLeft=true]{padding-left:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small[hasIconRight=true]{padding-right:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small[hasLabel=false]{padding:5px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small>[class*=libs-ui-button-icon]{font-size:var(--libs-ui-button-size-icon-small, 16px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small span,.libs-ui-button.libs-ui-button-theme.libs-ui-button-small .libs-ui-button-label{font-size:var(--libs-ui-button-size-small-font-size, 12px);font-family:var(--libs-ui-font-family-name, \"Arial\");font-weight:500;line-height:var(--libs-ui-button-size-small-line-height, 18px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller[hasLabel=true]{padding:1px 12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller[hasIconLeft=true]{padding-left:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller[hasIconRight=true]{padding-right:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller[hasLabel=false]{padding:1px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller>[class*=libs-ui-button-icon]{font-size:var(--libs-ui-button-size-icon-smaller, 16px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller span,.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller .libs-ui-button-label{font-size:var(--libs-ui-button-size-smaller-font-size, 11px);line-height:var(--libs-ui-button-size-smaller-line-height, 16px);font-family:var(--libs-ui-font-family-name, \"Arial\");font-weight:500}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color{color:var(--libs-ui-button-other-color-text, white);background:var(--libs-ui-button-other-color-background, #226ff5);border:1px solid var(--libs-ui-button-other-color-border, #226ff5)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text, white)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:hover,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[isPending=true]{color:var(--libs-ui-button-other-color-text-hover, white);background:var(--libs-ui-button-other-color-background-hover, #4e8cf7);border:1px solid var(--libs-ui-button-other-color-border-hover, #4e8cf7)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:hover>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[isPending=true]>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-hover, white)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:active,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[active=true],.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:focus,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[isClick=true]{color:var(--libs-ui-button-other-color-text-active, white);background:var(--libs-ui-button-other-color-background-active, #1b59c4);border:1px solid var(--libs-ui-button-other-color-border-active, #1b59c4)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:active>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[active=true]>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:focus>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[isClick=true]>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-active, white)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-disable{cursor:not-allowed;color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important;background:var(--libs-ui-button-other-color-background-disable, #f8f9fa);border:1px solid var(--libs-ui-button-other-color-border-disable, #f8f9fa)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-disable>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important}.libs-ui-button.libs-ui-button-theme.libs-ui-button-disable:hover{color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important;background:var(--libs-ui-button-other-color-background-disable, #f8f9fa);border:1px solid var(--libs-ui-button-other-color-border-disable, #f8f9fa)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-disable:hover>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important}.libs-ui-button.libs-ui-button-theme[isPending=true]{cursor:not-allowed;pointer-events:none}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link{padding:0;background:none;border:none}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link:hover,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link[isPending=true]{background:none;border:none}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link:active,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link[active=true],.libs-ui-button.libs-ui-button-theme.libs-ui-button-link:focus,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link[isClick=true]{background:none;border:none}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color{color:var(--libs-ui-button-link-other-color-text, #226ff5)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-link-other-color-text, #226ff5)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:hover,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[isPending=true]{color:var(--libs-ui-button-link-other-color-text-hover, #4e8cf7)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:hover>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[isPending=true]>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-link-other-color-text-hover, #4e8cf7)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:active,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[active=true],.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:focus,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[isClick=true]{color:var(--libs-ui-button-link-other-color-text-active, #1b59c4)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:active>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[active=true]>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:focus>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[isClick=true]>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-link-other-color-text-hover, #1b59c4)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-disable{cursor:not-allowed;pointer-events:none;color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-disable>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link[isPending=true]{cursor:not-allowed;pointer-events:none}.mo-button-custom-color-icon:before{color:inherit!important}\n"], dependencies: [{ kind: "directive", type: NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "ngmodule", type: TranslateModule }, { kind: "pipe", type: i1.TranslatePipe, name: "translate" }, { kind: "component", type: LibsUiComponentsSpinnerComponent, selector: "libs_ui-components-spinner", inputs: ["type", "size"] }, { kind: "component", type: LibsUiComponentsPopoverComponent, selector: "libs_ui-components-popover,[LibsUiComponentsPopoverDirective]", inputs: ["debugId", "flagMouse", "type", "mode", "config", "ignoreShowPopover", "elementRefCustom", "initEventInElementRefCustom", "classInclude", "ignoreHiddenPopoverContentWhenMouseLeave", "ignoreStopPropagationEvent", "ignoreCursorPointerModeLikeClick", "isAddContentToParentDocument", "ignoreClickOutside"], outputs: ["outEvent", "outChangStageFlagMouse", "outEventPopoverContent", "outFunctionsControl"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LibsUiComponentsButtonsButtonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'libs_ui-components-buttons-button', standalone: true, imports: [
                        NgStyle, TranslateModule,
                        LibsUiComponentsSpinnerComponent,
                        LibsUiComponentsPopoverComponent
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<libs_ui-components-popover [type]=\"popover().type || 'other'\"\n  [mode]=\"popover().mode || 'hover'\"\n  [ignoreHiddenPopoverContentWhenMouseLeave]=\"popover().ignoreHiddenPopoverContentWhenMouseLeave || false\"\n  [ignoreShowPopover]=\"popover().config ? !!popover().ignoreShowPopover : true\"\n  [elementRefCustom]=\"popover().elementRefCustom\"\n  [config]=\"popover().config || {}\"\n  [flagMouse]=\"flagMouse()\"\n  [ignoreStopPropagationEvent]=\"ignoreStopPropagationEvent()\"\n  (outFunctionsControl)=\"handlerPopoverControlEvent($event)\"\n  (outEvent)=\"handlerPopoverEvent($event)\">\n  <button #buttonEl\n    [class]=\"classBinding()\"\n    [class.libs-ui-button-disable]=\"disable()\"\n    [class.pointer-events-none]=\"disable() && !ignorePointerEvent()\"\n    [attr.isPending]=\"isPending()\"\n    [attr.isClick]=\"isClick()\"\n    [attr.tabindex]=\"ignoreFocusWhenInputTab()?'-1':'0'\"\n    [attr.hasLabel]=\"((label() || ' ') | translate) !== ' '\"\n    [attr.hasIconLeft]=\"!!classIconLeft()\"\n    [attr.hasIconRight]=\"!!classIconRight()\"\n    [attr.active]=\"!!isActive()\"\n    [ngStyle]=\"styleButton()\"\n    (click)=\"handlerClick($event)\">\n    @if (imageLeft(); as imageConfig) {\n      <img [src]=\"imageConfig.src\"\n        [class]=\"imageConfig.classInclude || 'mr-[8px]'\" />\n    }\n    @if (classIconLeft() && (!iconOnlyType() || (iconOnlyType() && !isPending()))) {\n      <i [attr.iconOnlyType]=\"iconOnlyType()\"\n        [class]=\"classIconLeft() + ' libs-ui-button-icon-left'\"\n        [ngStyle]=\"styleIconLeft()\">\n      </i>\n    }\n    @if (!iconOnlyType()) {\n      <libs_ui-components-popover [type]=\"'text'\"\n        [config]=\"{\n        zIndex: zIndex(),\n        width: widthLabelPopover()\n      }\"\n        [class]=\"(classLabel() || '') + ' libs-ui-button-label'\"\n        [innerHtml]=\"(label() || ' ') | translate\"\n        [ignoreStopPropagationEvent]=\"ignoreStopPropagationEvent()\" />\n    }\n    @if (classIconRight() && (!iconOnlyType() || (iconOnlyType() && !isPending()))) {\n      <i [attr.iconOnlyType]=\"iconOnlyType()\"\n        [class]=\"classIconRight()+' libs-ui-button-icon-right'\"></i>\n    }\n    @if (isPending()) {\n      <div class=\"relative\"\n        [class.w-[16px]]=\"!typeButton() && !iconOnlyType()\"\n        [class.left-[16px]]=\"!typeButton() && !iconOnlyType()\"\n        [class.ml-[8px]]=\"typeButton() && !iconOnlyType()\">\n        <libs_ui-components-spinner [type]=\"typeIconLoading()\"\n          [size]=\"sizeButton() === 'large'?'medium':sizeButton() === 'smaller'?'smaller':'small'\" />\n      </div>\n    }\n  </button>\n</libs_ui-components-popover>\n", styles: [".libs-ui-button{display:flex;align-items:center;text-align:center;color:#fff;cursor:pointer}.libs-ui-button.libs-ui-button-theme{display:flex;align-items:center;font-size:var(--libs-ui-button-size-medium-font-size, 12px);line-height:var(--libs-ui-button-size-medium-line-height, 18px);text-align:center;color:#fff;border:none;border-radius:4px;cursor:pointer}.libs-ui-button.libs-ui-button-theme:focus,.libs-ui-button.libs-ui-button-theme[isClick=true]{outline:none;box-shadow:none}.libs-ui-button.libs-ui-button-theme .libs-ui-button-icon-left[iconOnlyType=false]{margin-right:8px}.libs-ui-button.libs-ui-button-theme .libs-ui-button-icon-right[iconOnlyType=false]{margin-left:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large{border-radius:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large[hasLabel=true]{padding:9px 16px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large>[class*=libs-ui-button-icon]{font-size:var(--libs-ui-button-size-icon-large, 20px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large[hasIconLeft=true]{padding-left:12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large[hasIconRight=true]{padding-right:12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large[hasLabel=false]{padding:11px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-large span,.libs-ui-button.libs-ui-button-theme.libs-ui-button-large .libs-ui-button-label{font-size:var(--libs-ui-button-size-large-font-size, 16px);font-family:var(--libs-ui-font-family-name, \"Arial\");font-weight:500;line-height:var(--libs-ui-button-size-large-line-height, 24px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium[hasLabel=true]{padding:6px 16px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium[hasIconLeft=true]{padding-left:12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium[hasIconRight=true]{padding-right:12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium[hasLabel=false]{padding:7px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium>[class*=libs-ui-button-icon]{font-size:var(--libs-ui-button-size-icon-medium, 16px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium span,.libs-ui-button.libs-ui-button-theme.libs-ui-button-medium .libs-ui-button-label{font-size:var(--libs-ui-button-size-medium-font-size, 12px);line-height:var(--libs-ui-button-size-medium-line-height, 18px);font-family:var(--libs-ui-font-family-name, \"Arial\");font-weight:500}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small[hasLabel=true]{padding:4px 12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small[hasIconLeft=true]{padding-left:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small[hasIconRight=true]{padding-right:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small[hasLabel=false]{padding:5px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small>[class*=libs-ui-button-icon]{font-size:var(--libs-ui-button-size-icon-small, 16px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-small span,.libs-ui-button.libs-ui-button-theme.libs-ui-button-small .libs-ui-button-label{font-size:var(--libs-ui-button-size-small-font-size, 12px);font-family:var(--libs-ui-font-family-name, \"Arial\");font-weight:500;line-height:var(--libs-ui-button-size-small-line-height, 18px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller[hasLabel=true]{padding:1px 12px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller[hasIconLeft=true]{padding-left:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller[hasIconRight=true]{padding-right:8px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller[hasLabel=false]{padding:1px}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller>[class*=libs-ui-button-icon]{font-size:var(--libs-ui-button-size-icon-smaller, 16px)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller span,.libs-ui-button.libs-ui-button-theme.libs-ui-button-smaller .libs-ui-button-label{font-size:var(--libs-ui-button-size-smaller-font-size, 11px);line-height:var(--libs-ui-button-size-smaller-line-height, 16px);font-family:var(--libs-ui-font-family-name, \"Arial\");font-weight:500}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color{color:var(--libs-ui-button-other-color-text, white);background:var(--libs-ui-button-other-color-background, #226ff5);border:1px solid var(--libs-ui-button-other-color-border, #226ff5)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text, white)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:hover,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[isPending=true]{color:var(--libs-ui-button-other-color-text-hover, white);background:var(--libs-ui-button-other-color-background-hover, #4e8cf7);border:1px solid var(--libs-ui-button-other-color-border-hover, #4e8cf7)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:hover>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[isPending=true]>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-hover, white)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:active,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[active=true],.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:focus,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[isClick=true]{color:var(--libs-ui-button-other-color-text-active, white);background:var(--libs-ui-button-other-color-background-active, #1b59c4);border:1px solid var(--libs-ui-button-other-color-border-active, #1b59c4)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:active>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[active=true]>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color:focus>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-other-color[isClick=true]>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-active, white)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-disable{cursor:not-allowed;color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important;background:var(--libs-ui-button-other-color-background-disable, #f8f9fa);border:1px solid var(--libs-ui-button-other-color-border-disable, #f8f9fa)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-disable>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important}.libs-ui-button.libs-ui-button-theme.libs-ui-button-disable:hover{color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important;background:var(--libs-ui-button-other-color-background-disable, #f8f9fa);border:1px solid var(--libs-ui-button-other-color-border-disable, #f8f9fa)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-disable:hover>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important}.libs-ui-button.libs-ui-button-theme[isPending=true]{cursor:not-allowed;pointer-events:none}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link{padding:0;background:none;border:none}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link:hover,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link[isPending=true]{background:none;border:none}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link:active,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link[active=true],.libs-ui-button.libs-ui-button-theme.libs-ui-button-link:focus,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link[isClick=true]{background:none;border:none}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color{color:var(--libs-ui-button-link-other-color-text, #226ff5)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-link-other-color-text, #226ff5)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:hover,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[isPending=true]{color:var(--libs-ui-button-link-other-color-text-hover, #4e8cf7)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:hover>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[isPending=true]>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-link-other-color-text-hover, #4e8cf7)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:active,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[active=true],.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:focus,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[isClick=true]{color:var(--libs-ui-button-link-other-color-text-active, #1b59c4)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:active>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[active=true]>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color:focus>[class*=libs-ui-button-icon]:before,.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-link-other-color[isClick=true]>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-link-other-color-text-hover, #1b59c4)}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-disable{cursor:not-allowed;pointer-events:none;color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link.libs-ui-button-disable>[class*=libs-ui-button-icon]:before{color:var(--libs-ui-button-other-color-text-disable, #cdd0d6)!important}.libs-ui-button.libs-ui-button-theme.libs-ui-button-link[isPending=true]{cursor:not-allowed;pointer-events:none}.mo-button-custom-color-icon:before{color:inherit!important}\n"] }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { LibsUiComponentsButtonsButtonComponent };
//# sourceMappingURL=libs-ui-components-buttons-button.mjs.map
